@@ -1,7 +1,9 @@
 skip_if_no_auth()
 
 test_that("measure_get_measures", {
-  res <- measure_get_measures(sample(1000:9999, 1))
+  vcr::use_cassette("measure_get_measures", {
+    res <- measure_get_measures(1227)
+  })
 
   n_cols <- length(names(res))
 
